pub enum IniMode {
Simple,
SimpleTrimmed,
}Expand description
Describes a method for parsing ini files.
The ini format isn’t a universally agreed upon standard, and it can have different rules depending on the program it is written for.
Some ini files will successfully parse on some programs, but not so on others.
Variants
Simple
Simple X=Y, where everything is passed through.
There are some restrictions to this:
- Keys, values, and sections cannot be multi-line
- Keys cannot contain
=characters - Keys cannot start with
;,#, or[ - Comments must exist in their own lines with no whitespace before the comment delimiter
SimpleTrimmed
Same as Simple, but trim whitespace for keys and values.
For example, key = value has the same meaning as key=value.
This adds two additional restrictions:
- Keys cannot end with whitespace
- Values cannot begin with whitespace